const fz = require('zigbee-herdsman-converters/converters/fromZigbee');
const tz = require('zigbee-herdsman-converters/converters/toZigbee');
const exposes = require('zigbee-herdsman-converters/lib/exposes');
const modernExtend = require('zigbee-herdsman-converters/lib/modernExtend');
const e = exposes.presets;
const ea = exposes.access;
const tuya = require('zigbee-herdsman-converters/lib/tuya');
const reporting = require('zigbee-herdsman-converters/lib/reporting');

const definition = {
     fingerprint: [
         {
            modelID: 'TS0601',
            manufacturerName: '_TZE200_o7vduidq',
        },
    ],
    model: 'ERC22-2-Z',
    vendor: 'BOX',
    description: 'ERC2202-Z 2 gang zigbee switch',
    fromZigbee: [tuya.fz.datapoints, fz.on_off],
    toZigbee: [tuya.tz.datapoints, tz.on_off],

    configure: async (device, coordinatorEndpoint) => {
        await tuya.configureMagicPacket(device, coordinatorEndpoint);
    },

    exposes: [
        e.switch().withEndpoint("l1").setAccess("state", ea.STATE_SET),
        e.switch().withEndpoint("l2").setAccess("state", ea.STATE_SET),
    ],

    meta: {
        multiEndpoint: true,
        tuyaDatapoints: [
                [19, 'state_l1', tuya.valueConverter.onOff], // send and report, bool
                [20, 'state_l2', tuya.valueConverter.onOff], // send and report, bool
                [17, 'standartscene', tuya.valueConverter.raw], // raw: btnid+ gid + sid + btnid + gid + sid 000000010000000e000000020000000000
                [1, 'scene1', tuya.valueConverter.raw], // Enum Value: scene
                [2, 'scene2', tuya.valueConverter.raw], // Enum Value: scene
                [3, 'scene3', tuya.valueConverter.raw], // Enum Value: scene
                [4, 'scene4', tuya.valueConverter.raw], // Enum Value: scene
                [5, 'scene5', tuya.valueConverter.raw], // Enum Value: scene
                [6, 'scene6', tuya.valueConverter.raw], // Enum Value: scene
                [7, 'scene7', tuya.valueConverter.raw], // Enum Value: scene
                [8, 'scene8', tuya.valueConverter.raw], // Enum Value: scene
                [9, 'scene9', tuya.valueConverter.raw], // Enum Value: scene
                [10, 'scene10', tuya.valueConverter.raw], // Enum Value: scene

        ],
    },
};

module.exports = definition;

